aboutsummaryrefslogtreecommitdiffstats
path: root/src/programs.asm
diff options
context:
space:
mode:
authoruser <user@clank>2026-07-18 00:38:38 +0200
committeruser <user@clank>2026-07-18 00:38:38 +0200
commitba2d7ae1d7b319645b10aaa31a7f664f9f80c25c (patch)
treee01e6c7c710a661defe2515ff9657f08cddcb283 /src/programs.asm
parenttools: gbtype prints hub errors to stderr and exits 1 (diff)
downloadgbos-ba2d7ae1d7b319645b10aaa31a7f664f9f80c25c.tar.gz
gbos-ba2d7ae1d7b319645b10aaa31a7f664f9f80c25c.tar.xz
gbos-ba2d7ae1d7b319645b10aaa31a7f664f9f80c25c.zip
refactor: c/ -> usr/, compiled program blobs out of the source tree
Userland sources live in usr/ (fits the Unix theme better than 'c'). SDCC output .bin blobs land in build/usr/ with the other build artifacts instead of littering the source dir; programs.asm INCBINs them from there. Byte-identical ROM.
Diffstat (limited to '')
-rw-r--r--src/programs.asm62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/programs.asm b/src/programs.asm
index 36f9d02..92c736b 100644
--- a/src/programs.asm
+++ b/src/programs.asm
@@ -47,101 +47,101 @@ ProgHello:
; -----------------------------------------------------------------------------
; PROG_CHELLO (bank 5) - a program written in C, compiled with SDCC to a
; self-contained ROM-bank image (crt0 + libc + code) and included verbatim.
; Rebuild with: sh c/build.sh c/chello.c c/chello.bin
; -----------------------------------------------------------------------------
SECTION "prog_chello", ROMX[$4000], BANK[5]
ProgChello:
- INCBIN "c/chello.bin"
+ INCBIN "build/usr/chello.bin"
SECTION "prog_echo", ROMX[$4000], BANK[6]
ProgEcho:
- INCBIN "c/echo.bin"
+ INCBIN "build/usr/echo.bin"
SECTION "prog_true", ROMX[$4000], BANK[7]
ProgTrue:
- INCBIN "c/true.bin"
+ INCBIN "build/usr/true.bin"
SECTION "prog_false", ROMX[$4000], BANK[8]
ProgFalse:
- INCBIN "c/false.bin"
+ INCBIN "build/usr/false.bin"
SECTION "prog_uname", ROMX[$4000], BANK[9]
ProgUname:
- INCBIN "c/uname.bin"
+ INCBIN "build/usr/uname.bin"
SECTION "prog_pid", ROMX[$4000], BANK[10]
ProgPid:
- INCBIN "c/pid.bin"
+ INCBIN "build/usr/pid.bin"
SECTION "prog_cat", ROMX[$4000], BANK[11]
ProgCat:
- INCBIN "c/cat.bin"
+ INCBIN "build/usr/cat.bin"
SECTION "prog_wc", ROMX[$4000], BANK[12]
ProgWc:
- INCBIN "c/wc.bin"
+ INCBIN "build/usr/wc.bin"
SECTION "prog_head", ROMX[$4000], BANK[13]
ProgHead:
- INCBIN "c/head.bin"
+ INCBIN "build/usr/head.bin"
SECTION "prog_args", ROMX[$4000], BANK[14]
ProgArgs:
- INCBIN "c/args.bin"
+ INCBIN "build/usr/args.bin"
SECTION "prog_ls", ROMX[$4000], BANK[15]
ProgLs:
- INCBIN "c/ls.bin"
+ INCBIN "build/usr/ls.bin"
SECTION "prog_save", ROMX[$4000], BANK[16]
ProgSave:
- INCBIN "c/save.bin"
+ INCBIN "build/usr/save.bin"
SECTION "prog_rm", ROMX[$4000], BANK[17]
ProgRm:
- INCBIN "c/rm.bin"
+ INCBIN "build/usr/rm.bin"
SECTION "prog_ps", ROMX[$4000], BANK[18]
ProgPs:
- INCBIN "c/ps.bin"
+ INCBIN "build/usr/ps.bin"
SECTION "prog_kill", ROMX[$4000], BANK[19]
ProgKill:
- INCBIN "c/kill.bin"
+ INCBIN "build/usr/kill.bin"
SECTION "prog_spin", ROMX[$4000], BANK[20]
ProgSpin:
- INCBIN "c/spin.bin"
+ INCBIN "build/usr/spin.bin"
SECTION "prog_blk", ROMX[$4000], BANK[21]
ProgBlk:
- INCBIN "c/blk.bin"
+ INCBIN "build/usr/blk.bin"
SECTION "prog_mkdir", ROMX[$4000], BANK[22]
ProgMkdir:
- INCBIN "c/mkdir.bin"
+ INCBIN "build/usr/mkdir.bin"
SECTION "prog_count", ROMX[$4000], BANK[23]
ProgCount:
- INCBIN "c/count.bin"
+ INCBIN "build/usr/count.bin"
SECTION "prog_ptest", ROMX[$4000], BANK[24]
ProgPtest:
- INCBIN "c/ptest.bin"
+ INCBIN "build/usr/ptest.bin"
SECTION "prog_necho", ROMX[$4000], BANK[25]
ProgNecho:
- INCBIN "c/necho.bin"
+ INCBIN "build/usr/necho.bin"
SECTION "prog_wget", ROMX[$4000], BANK[26]
ProgWget:
- INCBIN "c/wget.bin"
+ INCBIN "build/usr/wget.bin"
SECTION "prog_chat", ROMX[$4000], BANK[27]
ProgChat:
- INCBIN "c/chat.bin"
+ INCBIN "build/usr/chat.bin"
SECTION "prog_netd", ROMX[$4000], BANK[28]
ProgNetd:
- INCBIN "c/netd.bin"
+ INCBIN "build/usr/netd.bin"
SECTION "prog_ping", ROMX[$4000], BANK[29]
ProgPing:
- INCBIN "c/ping.bin"
+ INCBIN "build/usr/ping.bin"
SECTION "prog_nslookup", ROMX[$4000], BANK[30]
ProgNslookup:
- INCBIN "c/nslookup.bin"
+ INCBIN "build/usr/nslookup.bin"
SECTION "prog_dhcp", ROMX[$4000], BANK[31]
ProgDhcp:
- INCBIN "c/dhcp.bin"
+ INCBIN "build/usr/dhcp.bin"
SECTION "prog_irc", ROMX[$4000], BANK[32]
ProgIrc:
- INCBIN "c/irc.bin"
+ INCBIN "build/usr/irc.bin"
; -----------------------------------------------------------------------------
; PROG_SH (bank 3) - the shell, now written in C (c/sh.c): parses >/</| and
; drives fork+exec+wait with I/O redirection. Command lookup + StrEqual/SkipName
; live in the kernel now (sys_lookup + NameTable + shell_lib).
; -----------------------------------------------------------------------------
SECTION "prog_sh", ROMX[$4000], BANK[3]
ProgSh:
- INCBIN "c/sh.bin"
+ INCBIN "build/usr/sh.bin"
; -----------------------------------------------------------------------------
; Shell string helpers (ROM0, always mapped).
@@ -47,101 +47,101 @@ ProgHello:
; PROG_CHELLO (bank 5) - a program written in C, compiled with SDCC to a
; self-contained ROM-bank image (crt0 + libc + code) and included verbatim.
-; Rebuild with: sh c/build.sh c/chello.c c/chello.bin
+; Rebuild with: make (or: sh usr/build.sh usr/chello.c build/usr/chello.bin)
; -----------------------------------------------------------------------------
SECTION "prog_chello", ROMX[$4000], BANK[5]
@@ -47,101 +47,101 @@ ProgHello:
; -----------------------------------------------------------------------------
-; PROG_SH (bank 3) - the shell, now written in C (c/sh.c): parses >/</| and
+; PROG_SH (bank 3) - the shell, now written in C (usr/sh.c): parses >/</| and
; drives fork+exec+wait with I/O redirection. Command lookup + StrEqual/SkipName
; live in the kernel now (sys_lookup + NameTable + shell_lib).